@@ -1,6 +1,6 @@
 import re
 import sys
-from typing import Optional, Sequence
+from typing import Dict, Optional, Sequence
 
 import click
 
@@ -168,11 +168,13 @@ def encode_options(kv):
         return {k: v}
 
 
-def use_interactive_ssm(is_a_tty: bool, **kwargs) -> bool:
+def use_interactive_ssm(is_a_tty: bool, command: Sequence[str], args: Dict) -> bool:
+    if command:
+        return False
     traditional_ssh_flags = ["D", "L", "N", "R", "T", "W", "w", "X", "Y"]
     for flag in traditional_ssh_flags:
         # if one of these flags is set to a truthy value then we need to speak traditional SSH
-        if flag in kwargs and kwargs[flag]:
+        if flag in args and args[flag]:
             return False
     return is_a_tty
 
@@ -230,7 +232,11 @@ def ssh(
     instance = get_ec2_client(client).load_instance_by_alias(destination)
     new_client = SAMLClientFactory.clone(client, aws_region=instance.region)
 
-    interactive_ssm = use_interactive_ssm(is_a_tty=sys.stdin.isatty(), **kwargs)
+    interactive_ssm = use_interactive_ssm(
+        is_a_tty=sys.stdin.isatty(),
+        command=command,
+        args=kwargs,
+    )
 
     if interactive_ssm:
         start_interactive_command(new_client, instance.instance_id, command=command)
